@@ -1,5 +1,5 @@
 /***************************************************************************
-* Copyright (c) 2016, Johan Mabille and Sylvain Corlay                     *
+* Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht    *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -502,7 +502,7 @@ namespace xt
                 }
                 // insert j at end of number
                 std::size_t idx = s.find_last_not_of(" ");
-                s.insert(idx + 1, "j");
+                s.insert(idx + 1, "i");
                 out << s;
                 ++m_it;
                 return out;
@@ -632,6 +632,11 @@ namespace xt
         {
             lim = print_options::print_options().edge_items;
         }
+        if (sz == 0)
+        {
+            out << "{}";
+            return out;
+        }
 
         precision_type temp_precision = (precision_type)out.precision();
         precision_type precision = temp_precision;
